**********
Snoweb SVG
**********

.. image:: https://img.shields.io/pypi/v/snowebsvg
    :target: https://pypi.org/project/snowebsvg/

.. image:: https://img.shields.io/pypi/pyversions/snowebsvg
    :target: https://pypi.org/project/snowebsvg/

.. image:: https://readthedocs.org/projects/snoweb-svg/badge/?version=latest
    :target: https://snoweb-svg.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://static.snoweb.fr/documents/logo-secondary.svg

Snoweb SVG is an open source project with SVG and CSS toolkit.


Features
********

- Micro interaction on hover
- Theme dark and light
- SVG code embed
- No javaScript required
- Possible integration with Django

Find all SVG at `svg.snoweb.fr <https://svg.snoweb.fr>`_.

Getting started
***************

1 - There are 2 ways to integrate SVGs in HTML :

- Add SVG code
- If you are using Django, follow this guide

2 - Here is the guide to using CSS toolkit :

- Add CSS files (core and collections) with the variables in the HTML


Contributing
************

If you're a SASS or Django developer, fork the repo and follow the guide :

- Configure development environment
- Create custom SVG
